@@ -12,7 +12,8 @@
 
 #include "dict-structures.h"
 #include "link-includes.h"
+#include "utilities.h"
 
 void insert_idiom(Dictionary dict, Dict_node *);
-bool  contains_underbar(const char *);
-bool  is_idiom_word(const char *);
+bool contains_underbar(const char *) ATTR_PURE;
+bool is_idiom_word(const char *) ATTR_PURE;
