@@ -22,7 +22,7 @@
 #include "parse/histogram.h"            // count_t
 
 // Can undefine VERIFY_MATCH_LIST when done debugging...
-#define VERIFY_MATCH_LIST
+// #define VERIFY_MATCH_LIST
 
 /* On a 64-bit machine, this struct should be exactly (6+2)*8=64 bytes long.
  * Lets try to keep it that way (for performance). */
@@ -63,7 +63,7 @@ struct Disjunct_struct
 	/* Shared by different steps. For what | when. */
 	union
 	{
-		uint32_t dup_hash;        /* Duplicate elimination | before pruning */
+		connector_hash_t dup_hash;/* Duplicate elimination | before pruning */
 		int32_t ordinal;          /* Generation mode | after d. elimination */
 	}; /* 4 bytes */
 
@@ -85,7 +85,7 @@ void free_categories(Sentence);
 void free_categories_from_disjunct_array(Disjunct *, unsigned int);
 unsigned int count_disjuncts(Disjunct *);
 Disjunct * catenate_disjuncts(Disjunct *, Disjunct *);
-Disjunct * eliminate_duplicate_disjuncts(Disjunct *, bool);
+unsigned int eliminate_duplicate_disjuncts(Disjunct *, bool);
 int left_connector_count(Disjunct *);
 int right_connector_count(Disjunct *);
 
