@@ -21,8 +21,13 @@
 #define IS_SENTENCE_WORD(sent, gword) (gword->unsplit_word == sent->wordgraph)
 
 Gword *gword_new(Sentence, const char *);
-size_t gwordlist_len(const Gword **);
 void gwordlist_append(Gword ***, Gword *);
+void gwordlist_free(Gword **);
+
+size_t gwordlist_len(const Gword **);
+const Gword ** gwordlist_copy(const Gword **);
+void gwordlist_cfree(const Gword **);
+
 void gword_set_print(const gword_set *);
 void print_lwg_path(Gword **, const char *);
 Gword *wg_get_sentence_word(const Sentence, Gword *);
@@ -39,6 +44,7 @@ Gword *find_real_unsplit_word(Gword *, bool);
 size_t wordgraph_pathpos_len(Wordgraph_pathpos *);
 Wordgraph_pathpos *wordgraph_pathpos_resize(Wordgraph_pathpos *, size_t);
 bool wordgraph_pathpos_add(Wordgraph_pathpos **, Gword *, bool, bool, bool);
+void wordgraph_pathpos_free(Wordgraph_pathpos *);
 
 const char *gword_status(Sentence, const Gword *);
 const char *gword_morpheme(Sentence sent, const Gword *w);
